@@ -32,10 +32,6 @@
 #                                                                              #
 ################################################################################
 
-from __future__ import absolute_import
-
-import six
-
 import github.GithubObject
 import github.NamedUser
 
@@ -151,7 +147,7 @@ class CommitComment(github.GithubObject.CompletableGithubObject):
         :param body: string
         :rtype: None
         """
-        assert isinstance(body, (str, six.text_type)), body
+        assert isinstance(body, str), body
         post_parameters = {
             "body": body,
         }
@@ -181,9 +177,7 @@ class CommitComment(github.GithubObject.CompletableGithubObject):
         :param reaction_type: string
         :rtype: :class:`github.Reaction.Reaction`
         """
-        assert isinstance(
-            reaction_type, (str, six.text_type)
-        ), "reaction type should be a string"
+        assert isinstance(reaction_type, str), "reaction type should be a string"
         assert reaction_type in [
             "+1",
             "-1",
