@@ -188,6 +188,12 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
     ):
         """
         :calls: `PATCH /repos/:owner/:repo/releases/:release_id <https://developer.github.com/v3/repos/releases/#edit-a-release>`_
+        :param name: string
+        :param message: string
+        :param draft: bool
+        :param prerelease: bool
+        :param tag_name: string
+        :param target_commitish: string
         :rtype: :class:`github.GitRelease.GitRelease`
         """
         assert tag_name is github.GithubObject.NotSet or isinstance(
@@ -209,8 +215,8 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
             "draft": draft,
             "prerelease": prerelease,
         }
-        # Do not set target_commitish to self.target_commitish when ommited, just don't send it
-        # alltogether in that case, in order to match the Github API behaviour. Only send it when set.
+        # Do not set target_commitish to self.target_commitish when omitted, just don't send it
+        # altogether in that case, in order to match the Github API behaviour. Only send it when set.
         if target_commitish is not github.GithubObject.NotSet:
             post_parameters["target_commitish"] = target_commitish
         headers, data = self._requester.requestJsonAndCheck(
@@ -229,6 +235,10 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
     ):
         """
         :calls: `POST https://<upload_url>/repos/:owner/:repo/releases/:release_id/assets <https://developer.github.com/v3/repos/releases/#upload-a-release-asset>`_
+        :param path: string
+        :param label: string
+        :param content_type: string
+        :param name: string
         :rtype: :class:`github.GitReleaseAsset.GitReleaseAsset`
         """
         assert isinstance(path, str), path
