@@ -25,9 +25,7 @@
 #                                                                              #
 ################################################################################
 
-
 import github.GithubObject
-import six
 
 
 class GitReleaseAsset(github.GithubObject.CompletableGithubObject):
@@ -155,10 +153,7 @@ class GitReleaseAsset(github.GithubObject.CompletableGithubObject):
         Delete asset from the release.
         :rtype: bool
         """
-        headers, data = self._requester.requestJsonAndCheck(
-            "DELETE",
-            self.url
-        )
+        headers, data = self._requester.requestJsonAndCheck("DELETE", self.url)
         return True
 
     def update_asset(self, name, label=""):
@@ -166,16 +161,11 @@ class GitReleaseAsset(github.GithubObject.CompletableGithubObject):
         Update asset metadata.
         :rtype: github.GitReleaseAsset.GitReleaseAsset
         """
-        assert isinstance(name, (str, six.text_type)), name
-        assert isinstance(label, (str, six.text_type)), label
-        post_parameters = {
-            "name": name,
-            "label": label
-        }
+        assert isinstance(name, str), name
+        assert isinstance(label, str), label
+        post_parameters = {"name": name, "label": label}
         headers, data = self._requester.requestJsonAndCheck(
-            "PATCH",
-            self.url,
-            input=post_parameters
+            "PATCH", self.url, input=post_parameters
         )
         return GitReleaseAsset(self._requester, headers, data, completed=True)
 
@@ -203,7 +193,9 @@ class GitReleaseAsset(github.GithubObject.CompletableGithubObject):
         if "label" in attributes:  # pragma no branch
             self._label = self._makeStringAttribute(attributes["label"])
         if "uploader" in attributes:  # pragma no branch
-            self._uploader = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["uploader"])
+            self._uploader = self._makeClassAttribute(
+                github.NamedUser.NamedUser, attributes["uploader"]
+            )
         if "content_type" in attributes:  # pragma no branch
             self._content_type = self._makeStringAttribute(attributes["content_type"])
         if "state" in attributes:  # pragma no branch
@@ -217,4 +209,6 @@ class GitReleaseAsset(github.GithubObject.CompletableGithubObject):
         if "updated_at" in attributes:  # pragma no branch
             self._updated_at = self._makeDatetimeAttribute(attributes["updated_at"])
         if "browser_download_url" in attributes:  # pragma no branch
-            self._browser_download_url = self._makeStringAttribute(attributes["browser_download_url"])
+            self._browser_download_url = self._makeStringAttribute(
+                attributes["browser_download_url"]
+            )
