@@ -31,10 +31,6 @@
 #                                                                              #
 ################################################################################
 
-from __future__ import absolute_import
-
-import six
-
 import github.GithubObject
 import github.HookResponse
 
@@ -161,16 +157,16 @@ class Hook(github.GithubObject.CompletableGithubObject):
         :param active: bool
         :rtype: None
         """
-        assert isinstance(name, (str, six.text_type)), name
+        assert isinstance(name, str), name
         assert isinstance(config, dict), config
         assert events is github.GithubObject.NotSet or all(
-            isinstance(element, (str, six.text_type)) for element in events
+            isinstance(element, str) for element in events
         ), events
         assert add_events is github.GithubObject.NotSet or all(
-            isinstance(element, (str, six.text_type)) for element in add_events
+            isinstance(element, str) for element in add_events
         ), add_events
         assert remove_events is github.GithubObject.NotSet or all(
-            isinstance(element, (str, six.text_type)) for element in remove_events
+            isinstance(element, str) for element in remove_events
         ), remove_events
         assert active is github.GithubObject.NotSet or isinstance(active, bool), active
         post_parameters = {
