@@ -104,7 +104,6 @@ class PaginatedList(PaginatedListBase):
     If you want to know the total number of items in the list::
 
         print(user.get_repos().totalCount)
-        print(len(user.get_repos()))
 
     You can also index them or take slices::
 
@@ -131,7 +130,7 @@ class PaginatedList(PaginatedListBase):
         headers=None,
         list_item="items",
     ):
-        PaginatedListBase.__init__(self)
+        super().__init__()
         self.__requester = requester
         self.__contentClass = contentClass
         self.__firstUrl = firstUrl
